@@ -19,81 +19,47 @@
 #' @param ppd Logical, if \code{TRUE}, variance decomposition is based on the
 #'   posterior predictive distribution, which is the correct way for Bayesian
 #'   non-Gaussian models.
+#' @param adjusted Logical, if \code{TRUE}, the adjusted (and conditional) ICC
+#'   is calculated, which reflects the uncertainty of all random effects (see
+#'   'Details'). \strong{Note} that if \code{adjusted = TRUE}, \strong{no}
+#'   additional information on the variance components is returned.
+#'
 #'
 #' @inheritParams hdi
 #'
 #' @return A numeric vector with all random intercept intraclass-correlation-coefficients.
-#'    Furthermore, between- and within-group variances as well as random-slope
-#'    variance are returned as attributes.
+#'    Furthermore, if \code{adjusted = FALSE}, between- and within-group variances
+#'    as well as random-slope variance are returned as attributes.
 #'    \cr \cr
 #'    For \code{stanreg} or \code{brmsfit} objects, the HDI for each statistic
 #'    is also  included as attribute.
 #'
 #' @references \itemize{
-#'               \item Aguinis H, Gottfredson RK, Culpepper SA. 2013. Best-Practice Recommendations for Estimating Cross-Level Interaction Effects Using Multilevel Modeling. Journal of Management 39(6): 1490–1528 (\doi{10.1177/0149206313478188})
-#'               \item Aly SS, Zhao J, Li B, Jiang J. 2014. Reliability of environmental sampling culture results using the negative binomial intraclass correlation coefficient. Springerplus 14(3) (\doi{10.1186/2193-1801-3-40})
-#'               \item Goldstein H, Browne W, Rasbash J. 2010. Partitioning Variation in Multilevel Models. Understanding Statistics, 1:4, 223-231 (\doi{10.1207/S15328031US0104_02})
-#'               \item Grace-Martion K. The Intraclass Correlation Coefficient in Mixed Models, \href{http://www.theanalysisfactor.com/the-intraclass-correlation-coefficient-in-mixed-models/}{web}
-#'               \item Hox J. 2002. Multilevel analysis: techniques and applications. Mahwah, NJ: Erlbaum
-#'               \item Rabe-Hesketh S, Skrondal A. 2012. Multilevel and longitudinal modeling using Stata. 3rd ed. College Station, Tex: Stata Press Publication
-#'               \item Raudenbush SW, Bryk AS. 2002. Hierarchical linear models: applications and data analysis methods. 2nd ed. Thousand Oaks: Sage Publications
-#'               \item Stryhn H, Sanchez J, Morley P, Booker C, Dohoo IR. 2006. Interpretation of variance parameters in multilevel Poisson regression models. Proceedings of the 11th International Symposium on Veterinary Epidemiology and Economics, 2006 Available at \url{http://www.sciquest.org.nz/node/64294}
-#'               \item Wu S, Crespi CM, Wong WK. 2012. Comparison of methods for estimating the intraclass correlation coefficient for binary responses in cancer prevention cluster randomized trials. Contempory Clinical Trials 33: 869-880 (\doi{10.1016/j.cct.2012.05.004})
-#'             }
-#'             Further helpful online-ressources:
-#'             \itemize{
-#'               \item \href{http://stats.stackexchange.com/questions/18088/intraclass-correlation-icc-for-an-interaction/28100#28100}{CrossValidated (2012) \emph{Intraclass correlation (ICC) for an interaction?}}
-#'               \item \href{http://stats.stackexchange.com/questions/113577/interpreting-the-random-effect-in-a-mixed-effect-model/113825#113825}{CrossValidated (2014) \emph{Interpreting the random effect in a mixed-effect model}}
-#'               \item \href{http://stats.stackexchange.com/questions/67247/how-to-partition-the-variance-explained-at-group-level-and-individual-level/67356#67356}{CrossValidated (2014) \emph{how to partition the variance explained at group level and individual level}}
-#'             }
+#'    \item Aguinis H, Gottfredson RK, Culpepper SA. 2013. Best-Practice Recommendations for Estimating Cross-Level Interaction Effects Using Multilevel Modeling. Journal of Management 39(6): 1490–1528 (\doi{10.1177/0149206313478188})
+#'    \item Goldstein H, Browne W, Rasbash J. 2010. Partitioning Variation in Multilevel Models. Understanding Statistics, 1:4, 223-231 (\doi{10.1207/S15328031US0104_02})
+#'    \item Grace-Martion K. The Intraclass Correlation Coefficient in Mixed Models, \href{http://www.theanalysisfactor.com/the-intraclass-correlation-coefficient-in-mixed-models/}{web}
+#'    \item Hox J. 2002. Multilevel analysis: techniques and applications. Mahwah, NJ: Erlbaum
+#'    \item Nakagawa S, Johnson P, Schielzeth H (2017) The coefficient of determination R2 and intra-class correlation coefficient from generalized linear mixed-effects models revisted and expanded. J. R. Soc. Interface 14. \doi{10.1098/rsif.2017.0213}
+#'    \item Rabe-Hesketh S, Skrondal A. 2012. Multilevel and longitudinal modeling using Stata. 3rd ed. College Station, Tex: Stata Press Publication
+#'    \item Raudenbush SW, Bryk AS. 2002. Hierarchical linear models: applications and data analysis methods. 2nd ed. Thousand Oaks: Sage Publications
+#'    \item Wu S, Crespi CM, Wong WK. 2012. Comparison of methods for estimating the intraclass correlation coefficient for binary responses in cancer prevention cluster randomized trials. Contempory Clinical Trials 33: 869-880 (\doi{10.1016/j.cct.2012.05.004})
+#'  }
+#'  Further helpful online-ressources:
+#'  \itemize{
+#'    \item \href{http://stats.stackexchange.com/questions/18088/intraclass-correlation-icc-for-an-interaction/28100#28100}{CrossValidated (2012) \emph{Intraclass correlation (ICC) for an interaction?}}
+#'    \item \href{http://stats.stackexchange.com/questions/113577/interpreting-the-random-effect-in-a-mixed-effect-model/113825#113825}{CrossValidated (2014) \emph{Interpreting the random effect in a mixed-effect model}}
+#'    \item \href{http://stats.stackexchange.com/questions/67247/how-to-partition-the-variance-explained-at-group-level-and-individual-level/67356#67356}{CrossValidated (2014) \emph{how to partition the variance explained at group level and individual level}}
+#'  }
 #'
 #'
 #' @note Some notes on why the ICC is useful, based on \cite{Grace-Martin}:
-#'       \itemize{
-#'        \item It can help you determine whether or not a linear mixed model is even necessary. If you find that the correlation is zero, that means the observations within clusters are no more similar than observations from different clusters. Go ahead and use a simpler analysis technique.
-#'        \item It can be theoretically meaningful to understand how much of the overall variation in the response is explained simply by clustering. For example, in a repeated measures psychological study you can tell to what extent mood is a trait (varies among people, but not within a person on different occasions) or state (varies little on average among people, but varies a lot across occasions).
-#'        \item It can also be meaningful to see how the ICC (as well as the between and within cluster variances) changes as variable are added to the model.
-#'       }
-#'       In short, the ICC can be interpreted as \dQuote{the proportion of the variance
-#'       explained by the grouping structure in the population} \cite{(Hox 2002: 15)}.
-#'       \cr \cr
-#'       Usually, the ICC is calculated for the null model ("unconditional model").
-#'       However, according to \cite{Raudenbush and Bryk (2002)} or
-#'       \cite{Rabe-Hesketh and Skrondal (2012)} it is also feasible to compute the ICC
-#'       for full models with covariates ("conditional models") and compare how
-#'       much a level-2 variable explains the portion of variation in the grouping
-#'       structure (random intercept).
-#'       \cr \cr
-#'       \strong{Caution:} For three-level-models, depending on the nested structure
-#'       of the model, the ICC only reports the proportion of variance explained
-#'       for each grouping level. However, the proportion of variance for specific
-#'       levels related to each other (e.g., similarity of level-1-units within
-#'       level-2-units or level-2-units within level-3-units) must be computed
-#'       manually. Use \code{\link{get_re_var}} to get the between-group-variances
-#'       and residual variance of the model, and calculate the ICC for the various level
-#'       correlations.
-#'       \cr \cr
-#'       For example, for the ICC between level 1 and 2: \cr
-#'       \code{sum(get_re_var(fit)) / (sum(get_re_var(fit)) + get_re_var(fit, "sigma_2"))}
-#'       \cr \cr
-#'       or for the ICC between level 2 and 3: \cr
-#'       \code{get_re_var(fit)[2] / sum(get_re_var(fit))}
-#'
-#' @details The ICC is calculated by dividing the between-group-variance (random
-#'   intercept variance) by the total variance (i.e. sum of between-group-variance
-#'   and within-group (residual) variance). \cr \cr
-#'   The calculation of the ICC for generalized linear mixed models with binary outcome is based on
-#'   \cite{Wu et al. (2012)}. For Poisson multilevel models, please refer to \cite{Stryhn et al. (2006)}.
-#'   \cite{Aly et al. (2014)} describe computation of ICC for negative binomial models.
-#'   \cr \cr
-#'   \strong{Caution:} For models with random slopes and random intercepts,
-#'   the ICC would differ at each unit of the predictors. Hence, the ICC for these
-#'   kind of models cannot be understood simply as proportion of variance
-#'   (see \cite{Goldstein et al. 2010}). For convenience reasons, as the
-#'   \code{icc()} function also extracts the different random effects
-#'   variances, the ICC for random-slope-intercept-models is reported
-#'   nonetheless, but it is usually no meaningful summary of the
-#'   proportion of variances.
+#'    \itemize{
+#'      \item It can help you determine whether or not a linear mixed model is even necessary. If you find that the correlation is zero, that means the observations within clusters are no more similar than observations from different clusters. Go ahead and use a simpler analysis technique.
+#'      \item It can be theoretically meaningful to understand how much of the overall variation in the response is explained simply by clustering. For example, in a repeated measures psychological study you can tell to what extent mood is a trait (varies among people, but not within a person on different occasions) or state (varies little on average among people, but varies a lot across occasions).
+#'      \item It can also be meaningful to see how the ICC (as well as the between and within cluster variances) changes as variable are added to the model.
+#'    }
+#'    In short, the ICC can be interpreted as \dQuote{the proportion of the variance
+#'    explained by the grouping structure in the population} \cite{(Hox 2002: 15)}.
 #'   \cr \cr
 #'   The random effect variances indicate the between- and within-group
 #'   variances as well as random-slope variance and random-slope-intercept
@@ -105,23 +71,86 @@
 #'     \item Random-Intercept-Slope-covariance: tau.01
 #'     \item Random-Intercept-Slope-correlation: rho.01
 #'   }
-#'   If \code{ppd = TRUE}, \code{icc()} calculates a variance decomposition based on
-#'   the posterior predictive distribution. In this case, first, the draws from
-#'   the posterior predictive distribution \emph{not conditioned} on group-level
-#'   terms (\code{posterior_predict(..., re.form = NA)}) are calculated as well
-#'   as draws from this distribution \emph{conditioned} on \emph{all random effects}
-#'   (by default, unless specified else in \code{re.form}) are taken. Then, second,
-#'   the variances for each of these draws are calculated. The "ICC" is then the
-#'   ratio between these two variances. This is the recommended way to
-#'   analyse random-effect-variances for non-Gaussian models. It is then possible
-#'   to compare variances accross models, also by specifying different group-level
-#'   terms via the \code{re.form}-argument.
-#'   \cr \cr
-#'   Sometimes, when the variance of the posterior predictive distribution is
-#'   very large, the variance ratio in the output makes no sense, e.g. because
-#'   it is negative. In such cases, it might help to use a more robust measure
-#'   to calculate the central tendency of the variances. For example, use
-#'   \code{typical = "median"}.
+#'
+#' @details The ICC is calculated by dividing the between-group-variance (random
+#'    intercept variance) by the total variance (i.e. sum of between-group-variance
+#'    and within-group (residual) variance). \cr \cr
+#'    The calculation of the ICC for generalized linear mixed models with binary outcome is based on
+#'    \cite{Wu et al. (2012)}. For other distributions (negative binomial, poisson, ...),
+#'    calculation is based on \cite{Nakagawa et al. 2017}.
+#'    \cr \cr
+#'    \strong{ICC for unconditional and conditional models}
+#'    \cr \cr
+#'    Usually, the ICC is calculated for the null model ("unconditional model").
+#'    However, according to \cite{Raudenbush and Bryk (2002)} or
+#'    \cite{Rabe-Hesketh and Skrondal (2012)} it is also feasible to compute the ICC
+#'    for full models with covariates ("conditional models") and compare how
+#'    much a level-2 variable explains the portion of variation in the grouping
+#'    structure (random intercept).
+#'    \cr \cr
+#'    \strong{ICC for random-slope models}
+#'    \cr \cr
+#'    \strong{Caution:} For models with random slopes and random intercepts,
+#'    the ICC would differ at each unit of the predictors. Hence, the ICC for these
+#'    kind of models cannot be understood simply as proportion of variance
+#'    (see \cite{Goldstein et al. 2010}). For convenience reasons, as the
+#'    \code{icc()} function also extracts the different random effects
+#'    variances, the ICC for random-slope-intercept-models is reported
+#'    nonetheless, but it is usually no meaningful summary of the
+#'    proportion of variances.
+#'    \cr \cr
+#'    \strong{ICC for models with multiple or nested random effects}
+#'    \cr \cr
+#'    \strong{Caution:} By default, for three-level-models, depending on the
+#'    nested structure of the model, or for models with multiple random effects,
+#'    \code{icc()} only reports the proportion of variance explained for each
+#'    grouping level. Use \code{adjusted = TRUE} to calculate the adjusted and
+#'    conditional ICC.
+#'    \cr \cr
+#'    \strong{Adjusted and conditional ICC}
+#'    \cr \cr
+#'    If \code{adjusted = TRUE}, an adjusted and conditional ICC are calculated,
+#'    which take all sources of uncertainty (of \emph{all random effects})
+#'    into account to report an "adjusted" ICC, as well as the conditional ICC.
+#'    The latter also takes the fixed effects variances into account (see
+#'    \cite{Nakagawa et al. 2017}). If random effects are not nested and not
+#'    cross-classified, the adjusted (\code{adjusted = TRUE}) and unadjusted
+#'    (\code{adjusted = FALSE}) ICC are identical.
+#'    \cr \cr
+#'    \strong{ICC for specific group-levels}
+#'    \cr \cr
+#'    To calculate the proportion of variance for specific levels related to each
+#'    other (e.g., similarity of level-1-units within
+#'    level-2-units or level-2-units within level-3-units) must be computed
+#'    manually. Use \code{\link{get_re_var}} to get the between-group-variances
+#'    and residual variance of the model, and calculate the ICC for the various level
+#'    correlations.
+#'    \cr \cr
+#'    For example, for the ICC between level 1 and 2: \cr
+#'    \code{sum(get_re_var(fit)) / (sum(get_re_var(fit)) + get_re_var(fit, "sigma_2"))}
+#'    \cr \cr
+#'    or for the ICC between level 2 and 3: \cr
+#'    \code{get_re_var(fit)[2] / sum(get_re_var(fit))}
+#'    \cr \cr
+#'    \strong{ICC for Bayesian models}
+#'    \cr \cr
+#'    If \code{ppd = TRUE}, \code{icc()} calculates a variance decomposition based on
+#'    the posterior predictive distribution. In this case, first, the draws from
+#'    the posterior predictive distribution \emph{not conditioned} on group-level
+#'    terms (\code{posterior_predict(..., re.form = NA)}) are calculated as well
+#'    as draws from this distribution \emph{conditioned} on \emph{all random effects}
+#'    (by default, unless specified else in \code{re.form}) are taken. Then, second,
+#'    the variances for each of these draws are calculated. The "ICC" is then the
+#'    ratio between these two variances. This is the recommended way to
+#'    analyse random-effect-variances for non-Gaussian models. It is then possible
+#'    to compare variances accross models, also by specifying different group-level
+#'    terms via the \code{re.form}-argument.
+#'    \cr \cr
+#'    Sometimes, when the variance of the posterior predictive distribution is
+#'    very large, the variance ratio in the output makes no sense, e.g. because
+#'    it is negative. In such cases, it might help to use a more robust measure
+#'    to calculate the central tendency of the variances. For example, use
+#'    \code{typical = "median"}.
 #'
 #' @seealso \code{\link{re_var}}
 #'
@@ -138,6 +167,7 @@
 #' sleepstudy$mygrp <- sample(1:45, size = 180, replace = TRUE)
 #' fit2 <- lmer(Reaction ~ Days + (1 | mygrp) + (1 | Subject), sleepstudy)
 #' icc(fit2)
+#' icc(fit2, adjusted = TRUE)
 #'
 #' icc1 <- icc(fit1)
 #' icc2 <- icc(fit2)
@@ -182,9 +212,14 @@ icc <- function(x, ...) {
 
 #' @importFrom lme4 VarCorr fixef getME
 #' @importFrom stats formula
-#' @importFrom purrr map map_dbl map_lgl
+#' @importFrom purrr map map_dbl map_lgl map2
+#' @rdname icc
 #' @export
-icc.merMod <- function(x, ...) {
+icc.merMod <- function(x, adjusted = FALSE, ...) {
+
+  # compute adjusted and conditional ICC
+  if (adjusted) return(r2_mixedmodel(x, type = "icc"))
+
   # get family
   fitfam <- model_family(x)
 
@@ -213,7 +248,7 @@ icc.merMod <- function(x, ...) {
 
   if (is.null(sig)) {
     if (fitfam$is_bin)
-      sig <- sqrt((pi ^ 2) / 3)
+      sig <- sqrt((pi^2) / 3)
     else
       sig <- 1
   }
@@ -222,40 +257,32 @@ icc.merMod <- function(x, ...) {
   # residual variances, i.e.
   # within-cluster-variance (sigma^2)
 
-  if (fitfam$is_bin) {
+  if (fitfam$is_linear) {
+    # get residual standard deviation sigma
+    resid_var <- sig^2
+  } else if (fitfam$is_bin) {
     # for logistic models, we use pi / 3
-    resid_var <- (pi ^ 2) / 3
-  } else if (inherits(x, "glmerMod") && fitfam$is_negbin) {
-    # for negative binomial models, we use 1
-    resid_var <- 1
+    resid_var <- switch(
+      fitfam$link.fun,
+      logit = pi^2 / 3,
+      probit = 1,
+      badlink(fitfam$link.fun, fitfam$family)
+    )
   } else {
-    # for linear and poisson models, we have a clear residual variance
-    resid_var <- sig ^ 2
+    resid_var <- switch(
+      fitfam$link.fun,
+      log = logVarDist(x, null_model(x), fitfam, sig),
+      sqrt = 0.25,
+      badlink(fitfam$link.fun, fitfam$family)
+    )
   }
 
 
   # total variance, sum of random intercept and residual variances
   total_var <- sum(purrr::map_dbl(vars, ~ sum(.x)), resid_var)
 
-
-  # check whether we have negative binomial
-
-  if (fitfam$is_negbin) {
-    # for negative binomial models, we also need the intercept...
-    beta <- as.numeric(lme4::fixef(x)["(Intercept)"])
-    # ... and the theta value to compute the ICC
-    r <- lme4::getME(x, "glmer.nb.theta")
-
-    # make formula more readable
-
-    numerator <- (exp(tau.00) - 1)
-    denominator <- ((exp(total_var) - 1) + (exp(total_var) / r) + exp(-beta - (total_var / 2)))
-
-    ri.icc <- numerator / denominator
-  } else {
-    # random intercept icc
-    ri.icc <- tau.00 / total_var
-  }
+  # random intercept icc
+  ri.icc <- tau.00 / total_var
 
 
   # get random slope random intercept correlations
@@ -272,12 +299,20 @@ icc.merMod <- function(x, ...) {
     rnd_slope <- reva[has_rnd_slope]
 
     # get slope-intercept-correlations
-    rho.01 <- purrr::map_dbl(rnd_slope, ~ attr(.x, "correlation")[1, 2])
+    rho.01 <- purrr::map(rnd_slope, ~ attr(.x, "correlation")[-1, 1])
+
     # get standard deviations, multiplied
-    std_ <- purrr::map_dbl(rnd_slope, ~ prod(attr(.x, "stddev")))
+    std_ <- purrr::map(rnd_slope, function(.x) {
+      .sd <- attr(.x, "stddev")
+      .sd[1] * .sd[2:length(.sd)]
+    })
 
     # bind to matrix
-    tau.01 <- apply(cbind(rho.01, std_), MARGIN = 1, FUN = prod)
+    std.matrix <- purrr::map2(std_, rho.01, ~ cbind(.y, .x))
+    tau.01 <- purrr::map(std.matrix, ~ apply(.x, MARGIN = 1, FUN = prod))
+
+    rho.01 <- unlist(rho.01)
+    tau.01 <- unlist(tau.01)
 
     message("Caution! ICC for random-slope-intercept models usually not meaningful. See 'Note' in `?icc`.")
   }
@@ -319,8 +354,13 @@ icc.merMod <- function(x, ...) {
 #' @importFrom glmmTMB VarCorr fixef getME
 #' @importFrom stats family formula
 #' @importFrom purrr map map_dbl map_lgl
+#' @rdname icc
 #' @export
-icc.glmmTMB <- function(x, ...) {
+icc.glmmTMB <- function(x, adjusted = FALSE, ...) {
+
+  # compute adjusted and conditional ICC
+  if (adjusted) return(r2_mixedmodel(x, type = "icc"))
+
   # get family
   fitfam <- model_family(x)
 
@@ -350,7 +390,7 @@ icc.glmmTMB <- function(x, ...) {
 
   if (is.null(sig)) {
     if (fitfam$is_bin)
-      sig <- sqrt((pi ^ 2) / 3)
+      sig <- sqrt((pi^2) / 3)
     else
       sig <- 1
   }
@@ -359,37 +399,31 @@ icc.glmmTMB <- function(x, ...) {
   # residual variances, i.e.
   # within-cluster-variance (sigma^2)
 
-  if (fitfam$is_bin) {
+  if (fitfam$is_linear) {
+    resid_var <- sig^2
+  } else if (fitfam$is_bin) {
     # for logistic models, we use pi / 3
-    resid_var <- (pi ^ 2) / 3
+    resid_var <- switch(
+      fitfam$link.fun,
+      logit = pi^2 / 3,
+      probit = 1,
+      badlink(fitfam$link.fun, fitfam$family)
+    )
   } else {
-    # for linear and poisson models, we have a clear residual variance
-    resid_var <- sig ^ 2
+    resid_var <- switch(
+      fitfam$link.fun,
+      log = logVarDist(x, null_model(x), fitfam, sig),
+      sqrt = 0.25,
+      badlink(fitfam$link.fun, fitfam$family)
+    )
   }
 
 
   # total variance, sum of random intercept and residual variances
   total_var <- sum(purrr::map_dbl(vars, ~ sum(.x)), resid_var)
 
-
-  # check whether we have negative binomial
-
-  if (fitfam$is_negbin) {
-    # for negative binomial models, we also need the intercept...
-    beta <- as.numeric(glmmTMB::fixef(x)[[1]]["(Intercept)"])
-    # ... and the theta value to compute the ICC
-    r <- sig
-
-    # make formula more readable
-
-    numerator <- (exp(tau.00) - 1)
-    denominator <- ((exp(total_var) - 1) + (exp(total_var) / r) + exp(-beta - (total_var / 2)))
-
-    ri.icc <- numerator / denominator
-  } else {
-    # random intercept icc
-    ri.icc <- tau.00 / total_var
-  }
+  # random intercept icc
+  ri.icc <- tau.00 / total_var
 
 
   # get random slope random intercept correlations
@@ -406,12 +440,20 @@ icc.glmmTMB <- function(x, ...) {
     rnd_slope <- reva[has_rnd_slope]
 
     # get slope-intercept-correlations
-    rho.01 <- purrr::map_dbl(rnd_slope, ~ attr(.x, "correlation")[1, 2])
+    rho.01 <- purrr::map(rnd_slope, ~ attr(.x, "correlation")[-1, 1])
+
     # get standard deviations, multiplied
-    std_ <- purrr::map_dbl(rnd_slope, ~ prod(attr(.x, "stddev")))
+    std_ <- purrr::map(rnd_slope, function(.x) {
+      .sd <- attr(.x, "stddev")
+      .sd[1] * .sd[2:length(.sd)]
+    })
 
     # bind to matrix
-    tau.01 <- apply(cbind(rho.01, std_), MARGIN = 1, FUN = prod)
+    std.matrix <- purrr::map2(std_, rho.01, ~ cbind(.y, .x))
+    tau.01 <- purrr::map(std.matrix, ~ apply(.x, MARGIN = 1, FUN = prod))
+
+    rho.01 <- unlist(rho.01)
+    tau.01 <- unlist(tau.01)
 
     message("Caution! ICC for random-slope-intercept models usually not meaningful. See 'Note' in `?icc`.")
   }
@@ -522,8 +564,8 @@ icc.stanreg <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
     # get residual standard deviation sigma
     sig <- xdat[["sigma"]]
 
-    # for linear and poisson models, we have a clear residual variance
-    resid_var <- sig ^ 2
+    # residual variance
+    resid_var <- sig^2
 
     # total variance, sum of random intercept and residual variances
     total_var <- sjmisc::row_sums(
@@ -672,7 +714,7 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
 
 
     # retrieve only intercepts
-    vars <- purrr::map(reva, ~ .x$sd[, 1] ^ 2)
+    vars <- purrr::map(reva, ~ .x$sd[, 1]^2)
 
     # random intercept-variances, i.e.
     # between-subject-variance (tau 00)
@@ -687,7 +729,7 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
     # set default, if no residual variance is available
     if (is.null(sig)) {
       if (fitfam$is_bin)
-        sig <- sqrt((pi ^ 2) / 3)
+        sig <- sqrt((pi^2) / 3)
       else
         sig <- 1
     }
@@ -696,7 +738,7 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
     # residual variances, i.e.
     # within-cluster-variance (sigma^2)
 
-    resid_var <- sig ^ 2
+    resid_var <- sig^2
 
 
     # total variance, sum of random intercept and residual variances
@@ -706,26 +748,10 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
     # if not, just repeat the current value to match number of samples
     if (length(resid_var) == 1) resid_var <- rep(resid_var, length(total_var))
 
-    # check whether we have negative binomial
-
-    if (fitfam$is_negbin) {
-
-      # for negative binomial models, we also need the intercept...
-      beta <- as.numeric(brms::fixef(x)[[1]])
-      # ... and the theta value to compute the ICC
-      r <- sig
-
-      # make formula more readable
-
-      numerator <- purrr::map(tau.00, ~ exp(.x) - 1)
-      denominator <- ((exp(total_var) - 1) + (exp(total_var) / r) + exp(-beta - (total_var / 2)))
-
-      ri.icc <- purrr::map(numerator, ~ .x / denominator)
-    } else {
-      # random intercept icc
-      ri.icc <- purrr::map(tau.00, ~ .x / total_var)
-    }
+    # random intercept icc
+    ri.icc <- purrr::map(tau.00, ~ .x / total_var)
 
+    # random slope-variances (tau 11)
     tau.11 <- purrr::map_if(tau.11, is.null, ~ rep(NA, length(resid_var)))
 
     names(ri.icc) <- sprintf("icc_%s", names(ri.icc))
